@@ -16,7 +16,7 @@
 # }
 #
 # \arguments{
-#  \item{x}{A @numeric NxK @matrix.}
+#  \item{x}{A @numeric NxK @matrix with N >= 0.}
 #  \item{probs}{A @numeric @vector of J probabilities in [0,1].}
 #  \item{...}{Additional arguments passed to @see "stats::quantile".}
 #  \item{drop}{If TRUE, singleton dimensions in the result are dropped, 
@@ -41,18 +41,33 @@
 rowQuantiles <- function(x, probs=seq(from=0, to=1, by=0.25), ..., drop=TRUE) {
   naValue <- NA;
   storage.mode(naValue) <- storage.mode(x);
-  q <- matrix(naValue, nrow=nrow(x), ncol=length(probs));
+  nrow <- nrow(x);
+  q <- matrix(naValue, nrow=nrow, ncol=length(probs));
 
-  for (rr in seq(length=nrow(x))) {
-    q[rr,] <- quantile(x[rr,], probs=probs, ...);
+  if (nrow > 0L) {
+    # In order to seq the column names
+    t <- quantile(x[1L,], probs=probs, ...);
+    colnames(q) <- names(t);
+    q[1L,] <- t;
+
+    if (nrow >= 2L) {
+      for (rr in 2L:nrow) {
+        q[rr,] <- quantile(x[rr,], probs=probs, ...);
+      }
+    }
+  } else {
+    # Set the column names in case there are now rows
+    t <- quantile(0.0, probs=probs, ...);
+    colnames(q) <- names(t);
   }
 
   # Drop singleton dimensions?
-  if (drop)
+  if (drop) {
     q <- drop(q);
+  }
 
   q;
-}
+} # rowQuantiles()
 
 colQuantiles <- function(x, ...) {
   x <- t(x);
@@ -62,6 +77,8 @@ colQuantiles <- function(x, ...) {
 
 ############################################################################
 # HISTORY:
+# 2010-10-06 [HB] 
+# o Now the result of {row|col}Quantiles() contains column names.
 # 2008-03-26 [HB] 
 # o Created.
 ############################################################################
